@@ -3,7 +3,7 @@
 __author__ = "David Robillard"
 __copyright__ = "Copyright 2016-2020 David Robillard"
 __license__ = "ISC"
-__version__ = "0.24.7"
+__version__ = "0.24.14"
 __maintainer__ = "David Robillard"
 __email__ = "d@drobilla.net"
 __status__ = "Production"
@@ -1460,6 +1460,10 @@ class Instance(Structure):
             self.get_descriptor().connect_port(
                 self.get_handle(), port_index, data
             )
+        elif isinstance(data, Structure):
+            self.get_descriptor().connect_port(
+                self.get_handle(), port_index, cast(byref(data), c_void_p)
+            )
         elif type(data) == numpy.ndarray:
             self.get_descriptor().connect_port(
                 self.get_handle(),
